@@ -103,7 +103,7 @@ class colormap_color_func(object):
     """
     def __init__(self, colormap):
         import matplotlib.pyplot as plt
-        self.colormap = plt.cm.get_cmap(colormap)
+        self.colormap = plt.get_cmap(colormap)
 
     def __call__(self, word, font_size, position, orientation,
                  random_state=None, **kwargs):
@@ -291,7 +291,7 @@ class WordCloud(object):
             ``words_`` is now a dictionary
 
     ``layout_`` : list of tuples ((string, float), int, (int, int), int, color))
-        Encodes the fitted word cloud. For each word, it encodes the string, 
+        Encodes the fitted word cloud. For each word, it encodes the string,
         normalized frequency, font size, position, orientation, and color.
         The frequencies are normalized by the most commonly occurring word.
         The color is in the format of 'rgb(R, G, B).'
@@ -499,19 +499,22 @@ class WordCloud(object):
                 orientation = Image.ROTATE_90
             tried_other_orientation = False
             while True:
+                if font_size < self.min_font_size:
+                    # font-size went too small
+                    break
                 # try to find a position
                 font = ImageFont.truetype(self.font_path, font_size)
                 # transpose font optionally
                 transposed_font = ImageFont.TransposedFont(
                     font, orientation=orientation)
                 # get size of resulting text
-                box_size = draw.textsize(word, font=transposed_font)
+                box_size = draw.textbbox((0, 0), word, font=transposed_font, anchor="lt")
                 # find possible places using integral image:
-                result = occupancy.sample_position(box_size[1] + self.margin,
-                                                   box_size[0] + self.margin,
+                result = occupancy.sample_position(box_size[3] + self.margin,
+                                                   box_size[2] + self.margin,
                                                    random_state)
-                if result is not None or font_size < self.min_font_size:
-                    # either we found a place or font-size went too small
+                if result is not None:
+                    # Found a place
                     break
                 # if we didn't find a place, make font smaller
                 # but first try to rotate!
